LDM pqact.conf entries
======================

The [ldmconfig repo](https://github.com/akrherz/ldmconfig) provides some of the `ldmd.conf` entries for using these `pqact` files.  Here is an overview on what's found in each of the `pqact` files.

File | Description
--- | ---
pqact_afos.conf | Specific actions related to database archiving NWS Text Products.
pqact_gini.conf | Legacy GINI product processing.
pqact_iemingest.conf | Misc actions that the IEM runs, but not NWSChat.
pqact_nexrad.conf | Processing of NEXRAD products.
pqact_shef.conf | Processing of SHEF (hydrological) products.
pqact.conf | Main actions common to IEM and NWSChat.
